#pragma once

#include "abstractinterface.h"
#include "waylandbridge.h"

namespace kdk
{

class WaylandBridgeInterface : public AbstractInterface
{
    Q_OBJECT

public:
    WaylandBridgeInterface(QObject *parent = nullptr);
    ~WaylandBridgeInterface() override;

    WindowInfo requestInfo(WindowId wid) override;

    void requestActivate(WindowId wid) override;
    void requestClose(WindowId wid) override;
    void requestToggleKeepAbove(WindowId wid) override;
    void requestToggleMinimized(WindowId wid) override;
    void requestToggleMaximized(WindowId wid) override;
    WindowId activeWindow() override;

    QIcon iconFor(WindowId wid) override;
    QString titleFor(WindowId wid) override;
    QString windowGroupFor(WindowId wid) override;

    bool windowCanBeDragged(WindowId wid) override;
    bool windowCanBeMaximized(WindowId wid) override;

    void showCurrentDesktop() override;
    void hideCurrentDesktop() override;
    quint32 pid(WindowId wid) override;

    void setGeometry(QWindow *window, const QRect &rect) override;
    NET::WindowType windowType(WindowId wid) override;

    void setSkipTaskBar(QWindow *window, bool skip) override;
    void setSkipSwitcher(QWindow *window, bool skip) override;

    bool skipTaskBar(const WindowId &wid) override;
    bool skipSwitcher(const WindowId &wid) override;

    bool isShowingDesktop() override;
    void setOnAllDesktops(const WindowId &wid) override;

    void setPanelTakefocus(QWindow *window, bool flag) override;
    void demandAttention(const WindowId &wid) override;

private:
    WaylandBridge *m_bridge = nullptr;
    bool m_isShowingDesktop = false;

    void initWindowConnection(WaylandBridgeWindow* window);
    WaylandBridgeWindow *findWaylandBridgeWindow(WindowId wid);
};

}